GithubSignInParams class

Constructors

GithubSignInParams({required String clientId, required String clientSecret, required String redirectUrl, required String scopes})

Properties

clientId String
the github clientId
getter/setter pair
clientSecret String
the github clientSecret
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
redirectUrl String
the redirectUrl
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes String
the scopes of github api
getter/setter pair

Methods

combinedUrl() String
The structure of Url will be like this 'https://github.com/login/oauth/authorize?scope=user:email&client_id=XXXXXXXXXXXXXXX&redirect_uri=http://localhost:3000/auth/github/callback';
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited