GithubSignInResponse class
Constructors
- GithubSignInResponse({required SignInStatus status, String? accessToken, String? user, String? fullname, String? error})
Properties
- accessToken ↔ String?
-
the accessToken from Github
getter/setter pair
- error ↔ String?
-
the error message when call the github API
getter/setter pair
- fullname ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ SignInStatus
-
the SignInStatus status
getter/setter pair
- user ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited